@@ -274,7 +274,7 @@ int CF_getSystemName(string& sysName, string& errorMessage) {
 	// Modified by Ilsoo Byun(2008/10/02)
 	struct utsname uts;
         if (uname(&uts) < 0) {
-                errorMessage = "failed to get system name: " + (string) strerror(errno);
+                errorMessage = "Failed to get system name: " + (string) strerror(errno);
                 return FAILED;
         }
 
@@ -455,6 +455,20 @@ int CF_getBlockSize(const string& path, int& blocksize, int& num_blocks, string&
 	return OK;
 }
 
+int CF_getWhatisFL(const string& name, string& output, string& errorMessage)
+{
+	CF_assert(CF_runCommandFL("whatis "+name,output,errorMessage));
+	
+	int pos;
+	
+	if((pos=output.find_first_of('-'))!=string::npos)
+		output=output.substr(pos+2);
+	else
+		output.clear();
+	
+	return OK;
+}
+
 /* ---------------------------------------------------------------------------*/
 /*                             File manipulation                              */
 /* ---------------------------------------------------------------------------*/
