@@ -157,6 +157,9 @@ int CF_getMachineIP(string& ip, string& errorMessage);
 // http://www.faqs.org/docs/Linux-mini/Partition.html#BLOCKSIZE
 int CF_getBlockSize(const string& path, int& blocksize, int& num_blocks, string& errorMessage);
 
+// Get the first line of the response of "whatis" for a specified program name
+int CF_getWhatisFL(const string& name, string& output, string& errorMessage);
+
 /* ---------------------------------------------------------------------------*/
 /*                             File manipulation                              */
 /* ---------------------------------------------------------------------------*/
