@@ -80,13 +80,13 @@ string SMBIOS_processorInformationToString(const _processor_information& process
 void SMBIOS_cacheInformationToDefault(_cache_information& cache_information) {
 	_E_;
 	cache_information.handle = 0;
-	cache_information.operational_mode = 0; // Unknown
+	cache_information.operational_mode = 0;  // Unknown
 	cache_information.enabled = false;
-	cache_information.cache_level = 0; // Unknown
+	cache_information.cache_level = 0;       // Unknown
 	cache_information.granularity = 0;
 	cache_information.installed_size = 0;
-	cache_information.system_cache_type = 0x2; // Unknown
-	cache_information.associativity = 0x2; // Unknown
+	cache_information.system_cache_type = 0; // Unknown
+	cache_information.associativity = 0;     // Unknown
 	_L_;
 }
 
@@ -213,6 +213,8 @@ int SMBIOS_getProcessorsInformation(vector<_processor_information>& processors_i
     		processor_information.external_clock = ((unsigned char) char_ptr[0x12]) + (((unsigned char) char_ptr[0x13]) << 8);
     		// Max Speed
     		processor_information.max_speed = ((unsigned char) char_ptr[0x14]) + (((unsigned char) char_ptr[0x15]) << 8);
+    		// Current Speed
+    		processor_information.current_speed = ((unsigned char) char_ptr[0x16]) + (((unsigned char) char_ptr[0x17]) << 8);
     		// Status
     		temp = char_ptr[0x18];
     		processor_information.status = (temp & 0x7);
@@ -292,14 +294,21 @@ int SMBIOS_getProcessorsInformation(vector<_processor_information>& processors_i
     		cache_information.handle = ((unsigned char) char_ptr[0x2]) + (((unsigned char) char_ptr[0x3]) << 8);
     		// Cache Configuration
     		unsigned char temp = char_ptr[0x5];
-    		if ((temp & 0x3) == 0)
-    			cache_information.operational_mode = 3;
-    		if ((temp & 0x3) == 1)
-    			cache_information.operational_mode = 2;
-    		if ((temp & 0x3) == 2)
-    			cache_information.operational_mode = 4;
-    		if ((temp & 0x3) == 3)
-    			cache_information.operational_mode = 0;
+    		switch(temp & 0x3)
+    		{
+    			case 0:
+    				cache_information.operational_mode = 3;
+    				break;
+    			case 1:
+    				cache_information.operational_mode = 2;
+    				break;
+    			case 2:
+    				cache_information.operational_mode = 4;
+    				break;
+    			case 3:
+    				cache_information.operational_mode = 0;
+    				break;
+    		}
     		cache_information.enabled = false;
     		temp = char_ptr[0x6];
     		if (temp & 0x80)
@@ -315,10 +324,24 @@ int SMBIOS_getProcessorsInformation(vector<_processor_information>& processors_i
     		cache_information.installed_size = (temp & 0x78) + (((unsigned char) char_ptr[0xa]) << 8);
   			// System Cache Type
   			if (((_smbios_structure_header*) char_ptr)->length >= 0x12)
-  				cache_information.system_cache_type = (unsigned char) char_ptr[0x11];
+  			{
+  				if((unsigned char) char_ptr[0x11] ==0x1)
+  					cache_information.system_cache_type = 1;
+  				else if((unsigned char) char_ptr[0x11] == 0x2)
+  					cache_information.system_cache_type = 0;
+  				else
+  					cache_information.system_cache_type = (unsigned char) char_ptr[0x11]-1;
+  			}
   			// Associativity
   			if (((_smbios_structure_header*) char_ptr)->length >= 0x13)
-  				cache_information.associativity = (unsigned char) char_ptr[0x12];
+  			{
+  				if((unsigned char) char_ptr[0x12]==0x1)
+  					cache_information.associativity = 1;
+  				else if((unsigned char) char_ptr[0x12]==0x2)
+  					cache_information.associativity = 0;
+  				else
+  					cache_information.associativity = (unsigned char) char_ptr[0x12]-1;
+  			}
     		caches_information.push_back(cache_information);
     	}
     	number_of_smbios_structure--;
@@ -457,15 +480,15 @@ int SMBIOS_getStructure(vector<void*>& output,char *tableAddress, u16 structureC
 	u16 i;
 	u8 lasttype;
 	i = 0;
-
+	
 	output.clear();
 	while( i < structureCount)
 	{
 		lasttype = ((_smbios_structure_header *)tableAddress)->type;
-
+		
 		if( lasttype == Type )
 			output.push_back((void*)tableAddress);
-
+		
 		char* base = tableAddress + ((_smbios_structure_header*) tableAddress)->length;
 		if (base[0]==0 && base[1]==0)
 			tableAddress = base + 2;
@@ -477,7 +500,7 @@ int SMBIOS_getStructure(vector<void*>& output,char *tableAddress, u16 structureC
 		}
 		i++;
 	}
-
+	
 	return OK;
 }
 
@@ -486,10 +509,10 @@ const char *SMBIOS_getDmiString(_smbios_structure_header *dm, BYTE s)
 	//char *bp=(char *)dm->data;
 	char *bp;
 	size_t i, len;
-
+	
 	if(s==0)
 		return "Not Specified";
-
+	
 	bp=(char *)dm;
 	bp+=dm->length;
 	while(s>1 && *bp)
@@ -498,52 +521,50 @@ const char *SMBIOS_getDmiString(_smbios_structure_header *dm, BYTE s)
 		bp++;
 		s--;
 	}
-
-
+	
 	if(!*bp)
 		return "BAD INDEX";
-
+	
 	// ASCII filtering
 	len=strlen(bp);
 	for(i=0; i<len; i++)
 		if(bp[i]<32 || bp[i]==127)
 			bp[i]='.';
-
+	
 	return bp;
 }
 
 int SMBIOS_getSystemInformation(system_information& system_info,vector<string>& dmi_strings,string& errorMessage)
 {
-
 	vector<void*> infos;
 	void *start_ptr;
 	char *tableAddress;
 	_smbios_entry_point *anchor;
 	vector<int> indexes;
 	int index_max;
-
+	
 	if((start_ptr=SMBIOS_getRawData(_SMBIOS_ANCHOR_SEARCH_OFFSET,_SMBIOS_ANCHOR_SEARCH_RANGE,errorMessage))==NULL)
 		return FAILED;
-
+	
 	anchor=SMBIOS_getEntryPoint(start_ptr);
-
+	
 	if((tableAddress=(char*)SMBIOS_getRawData(anchor->structure_table_address,anchor->structure_table_length,errorMessage))==NULL)
 	{
 		free(start_ptr);
 		return FAILED;
 	}
-
+	
 	SMBIOS_getStructure(infos,tableAddress,anchor->number_of_smbios_structure,_SYSTEM_INFORMATION);
-
+	
 	memcpy(&system_info,infos[0],sizeof(system_information));
-
+	
 	if(system_info.length>=0x08)
 	{
 		indexes.push_back((int)system_info.manufacturer);
 		indexes.push_back((int)system_info.product_name);
 		indexes.push_back((int)system_info.version);
 		indexes.push_back((int)system_info.serial_number);
-
+		
 		if(system_info.length>=0x19)
 		{
 			if(system_info.length>=0x1B)
@@ -552,17 +573,16 @@ int SMBIOS_getSystemInformation(system_information& system_info,vector<string>&
 				indexes.push_back((int)system_info.family);
 			}
 		}
-
 	}
-
+	
 	index_max=*max_element(indexes.begin(), indexes.end());
-
+	
 	for(int i=0;i<=index_max;i++)
 		dmi_strings.push_back(SMBIOS_getDmiString((_smbios_structure_header*)infos[0],i));
-
+	
 	free(tableAddress);
 	free(start_ptr);
-
+	
 	return OK;
 }
 
